<?php
$conn = new mysqli("localhost", "root", "", "google_sheet_data");

if ($_SERVER["REQUEST_METHOD"] == "POST" && !empty($_POST['read_google_sheets'])) {
    if (isset($_POST['read_google_sheets'])) {
        // 1. Include Google API PHP Client library
        require_once 'vendor/autoload.php';

        // 2. Configure Google Sheets API credentials JSON
        putenv('GOOGLE_APPLICATION_CREDENTIALS=credentials.json');

        // 3. Create the API client instance
        $client = new Google_Client();
        $client->useApplicationDefaultCredentials();
        $client->setScopes([Google_Service_Sheets::SPREADSHEETS_READONLY]);
        $service = new Google_Service_Sheets($client);

        // 4.Define Google sheet ID and column range to import
        $spreadsheetId = 'GOOGLE SPREAD SHEET ID HERE';
        $range = 'Sheet1!A1:C';

        // 5. Read Google spreadsheet data
        $responseData = $service->spreadsheets_values->get($spreadsheetId, $range);
        $dataArray = $responseData->getValues();

        if (empty($dataArray)) {
            $message = "No data found.";
            $message_type = "error";
        } else {
            // Insert Google sheets row into the database
            $sql = "INSERT INTO tbl_google_sheet (first_name, last_name, company) VALUES (?, ?, ?)";
            $stmt = $conn->prepare($sql);
            foreach ($dataArray as $row) {
                $stmt->bind_param("sss", $row[0], $row[1], $row[2]);
                $stmt->execute();
            }
            $message = "Google Sheets data imported successfully.";
            $message_type = "success";

            $stmt->close();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>PHP Read Google Sheets</title>
    <link href="css/style.css" rel="stylesheet" type="text/css" />
    <link href="css/form.css" rel="stylesheet" type="text/css" />
    <link href="css/table.css" rel="stylesheet" type="text/css" />
    <style>
        .table-container {
            margin: 20px 0px;
        }
    </style>
</head>

<body>
    <div class="phppot-container">
        <h1 class="text-center">PHP Read Google Sheets</h1>
        <form method="POST">
            <button type="submit" name="read_google_sheets" class="">Read Google Sheets</button>

            <span id="loading" class="display-none">Reading from Google Sheets...</span>

        </form>
        <?php
        require_once 'google-sheet-table-data.php';
        ?>
        <?php if (!empty($message)) { ?>
            <div class="phppot-message <?php echo $message_type; ?>"><?php echo $message; ?></div>
        <?php } ?>
    </div>
    <script>
        document.querySelector('form').addEventListener('submit', function() {
            document.getElementById('loading').style.display = 'inline-block';
        });
    </script>
</body>

</html>